==> cmsmadesimple-1.5.3.tgz: cms/modules/FileManager/lang/ext/hu_HU.php <==
<?php
$lang['friendlyname'] = 'F&aacute;jlkezelő';
$lang['permission'] = 'A f&aacute;jlkezelő haszn&aacute;lata';
$lang['permissionadvanced'] = 'A f&aacute;jlkezelő halad&oacute; haszn&aacute;lata';
$lang['moddescription'] = 'K&eacute;pek &eacute;s mapp&aacute;k kezel&eacute;se a cmsms felt&ouml;ltő szekci&oacute;j&aacute;ban';
$lang['installed'] = 'Install&aacute;lt f&aacute;jlkezelő verzi&oacute;: %s';
$lang['postinstall'] = 'A F&aacute;jlkezelő modul telep&iacute;t&eacute;se megt&ouml;rt&eacute;nt';
$lang['uninstalled'] = 'A f&aacute;jlkezelő modul elt&aacute;vol&iacute;t&aacute;sa megt&ouml;rt&eacute;nt.';
$lang['really_uninstall'] = 'Biztosan elt&aacute;vol&iacute;tod a F&aacute;jlkezelő modult?';
$lang['upgraded'] = 'A F&aacute;jlkezelő modult sikeresen friss&iacute;tett&uuml;k %s verzi&oacute;ra';
$lang['fileview'] = 'F&aacute;jl n&eacute;zet';
$lang['switchtofileview'] = 'V&aacute;lt&aacute;s f&aacute;jl n&eacute;zetre';
$lang['settings'] = 'Be&aacute;ll&iacute;t&aacute;sok';
$lang['savesettings'] = 'Be&aacute;ll&iacute;t&aacute;sok ment&eacute;se';
$lang['filename'] = 'F&aacute;jln&eacute;v';
$lang['fileinfo'] = 'F&aacute;jlinfo';
$lang['fileowner'] = 'Tulajdonos';
$lang['fileperms'] = 'Jogosults&aacute;gok';
$lang['filesize'] = 'M&eacute;ret';
$lang['filedate'] = 'D&aacute;tum';
$lang['actions'] = 'Műveletek';
$lang['delete'] = 'T&ouml;rl&eacute;s';
$lang['notwritable'] = 'Nem &iacute;rhat&oacute;';
$lang['filetoobig'] = 't&uacute;l nagy. A felt&ouml;lt&eacute;st f&eacute;lbeszak&iacute;tottuk.';
$lang['unknown'] = 'Ismeretlen';
$lang['fileoutsideuploads'] = 'Nem m&oacute;dos&iacute;thatsz f&aacute;jlokat az uploads k&ouml;nyvt&aacute;ron k&iacute;v&uuml;l! (Ehhez a &quot;Kiterjesztett f&aacute;jl kezel&eacute;s&quot; jogra van sz&uuml;ks&eacute;g)';
$lang['writable'] = '&Iacute;rhat&oacute;';
$lang['writeprotected'] = '&Iacute;r&aacute;sv&eacute;dett';
$lang['bytes'] = 'b&aacute;jt';
$lang['kb'] = 'kb';
$lang['mb'] = 'mb';
$lang['files'] = 'f&aacute;jlok';
$lang['bytesin'] = 'b&aacute;jt ebben:';
$lang['in'] = '-ban(/ben)';
$lang['file'] = 'f&aacute;jl';
$lang['fileno'] = 'F&aacute;jl sz&aacute;ma';
$lang['subdirs'] = 'almapp&aacute;k';
$lang['subdir'] = 'almappa';
$lang['and'] = '&eacute;s';
$lang['confirmsingledelete'] = 'Biztos vagy benne?';
$lang['confirmsingledirdelete'] = 'Biztos, hogy ezt a mapp&aacute;t t&ouml;r&ouml;lni akarod?';
$lang['dirtreedeletesuccess'] = 'A tartalommal is b&iacute;r&oacute; mapp&aacute;t sikeresen t&ouml;r&ouml;lt&uuml;k';
$lang['dirtreedeletefail'] = 'Hiba t&ouml;rt&eacute;nta mappa t&ouml;rl&eacute;se k&ouml;zben. Ennek ellen&eacute;re lehet, hogy a tartalm&aacute;b&oacute;l hi&aacute;nyzik ez-az.';
$lang['singlefiledeletesuccess'] = 'A f&aacute;jlt sikeresen t&ouml;r&ouml;lt&uuml;k';
$lang['filedeletesuccess'] = 'sikeresen t&ouml;r&ouml;lve lett';
$lang['singlefiledeletefail'] = 'Hiba k&ouml;vetkezett a f&aacute;jl t&ouml;rl&eacute;se k&ouml;zben';
$lang['filedeletefail'] = ' nem lett t&ouml;r&ouml;lve egy hiba miatt';
$lang['singledirdeletesuccess'] = 'A mappa sikeresen t&ouml;r&ouml;lve lett';
$lang['singledirdeletefail'] = 'Hiba k&ouml;vetkezett a mappa t&ouml;rl&eacute;se k&ouml;zben (&uuml;res egy&aacute;ltal&aacute;n?)';
$lang['deleteselected'] = 'Kijel&ouml;lt f&aacute;jlok t&ouml;rl&eacute;se';
$lang['confirmselected'] = 'Biztos vagy benne?';
$lang['confirmdeleteselected'] = 'Biztos t&ouml;rl&ouml;d a kijel&ouml;lt f&aacute;jlokat?';
$lang['deleteselectedcancelled'] = 'A kijel&ouml;lt f&aacute;jlok t&ouml;rl&eacute;s&eacute;t megszak&iacute;tottuk';
$lang['recursetext'] = 'Bel&eacute;p&eacute;s az alk&ouml;nyvt&aacute;rakba is (rekurzi&oacute;)';
$lang['nofilesselected'] = 'Nincs kijel&ouml;lve f&aacute;jl';
$lang['moveselected'] = 'Kijel&ouml;lt f&aacute;jlok mozgat&aacute;sa';
$lang['copyselected'] = 'Kijel&ouml;lt f&aacute;jlok m&aacute;sol&aacute;sa';
$lang['selecttargetdir'] = 'V&aacute;laszd ki a c&eacute;lk&ouml;nyvt&aacute;rat a m&aacute;sol&aacute;shoz/mozgat&aacute;shoz';
$lang['movedto'] = 'mozgatva';
$lang['copiedto'] = 'm&aacute;solva';
$lang['couldnotmove'] = 'nem siker&uuml;lt mozgatni';
$lang['couldnotcopy'] = 'nem siker&uuml;lt m&aacute;solni';
$lang['rename'] = '&Aacute;tnevez&eacute;s';
$lang['newname'] = '&Uacute;j n&eacute;v:';
$lang['renamesuccess'] = 'A f&aacute;jlt sikeresen &aacute;tnevezt&uuml;k.';
$lang['renamefailure'] = 'A f&aacute;jl &aacute;tnevez&eacute;se nem siker&uuml;lt.';
$lang['renamecancelled'] = 'Az &aacute;tnevez&eacute;st f&eacute;lbeszak&iacute;tottuk.';
$lang['owner'] = 'Tulajdonos';
$lang['group'] = 'Csoport';
$lang['others'] = 'Mindenki m&aacute;s';
$lang['newpermissions'] = '&Uacute;j jogosults&aacute;gok:';
$lang['setpermissions'] = 'Jogosults&aacute;gok be&aacute;ll&iacute;t&aacute;sa';
$lang['permissionstyle'] = 'Jogosults&aacute;gok fajt&aacute;ja';
$lang['rwxstyle'] = 'rwx t&iacute;pius';
$lang['755style'] = '755 t&iacute;pus';
$lang['quickmode'] = 'Gyors chmod (kb. 777)';
$lang['chmod'] = 'Jogosults&aacute;gok megv&aacute;ltoztat&aacute;sa';
$lang['chmodselected'] = 'Jogosults&aacute;gok megv&aacute;ltoztat&aacute;sa a kijel&ouml;lt f&aacute;jlokra';
$lang['chmodsuccess'] = 'A f&aacute;jl sikeresen megkapta az &uacute;j jogokat';
$lang['chmodfailure'] = 'A f&aacute;jl jogosults&aacute;g&aacute;nak megv&aacute;ltoztat&aacute;sa nem siker&uuml;lt';
$lang['chmodcancelled'] = 'A jogosults&aacute;gok megv&aacute;ltoztat&aacute;s&aacute;t f&eacute;lbeszak&iacute;tottuk.';
$lang['dirchmodfailmulti'] = 'A k&ouml;nyvt&aacute;r jogainak megv&aacute;ltoztat&aacute;sa nem siker&uuml;lt, ennek ellen&eacute;re bizonyos benne levő f&aacute;jlok jogosults&aacute;gai megv&aacute;ltozhattak.';
$lang['dirchmodsuccessmulti'] = 'A k&ouml;nyvt&aacute;r &eacute;s a benne foglalt f&aacute;jlok jogosults&aacute;gainak megv&aacute;ltoztat&aacute;sa sikeres volt';
$lang['dirchmodsuccess'] = 'A k&ouml;nyvt&aacute;r megkapta az &uacute;j jogokat';
$lang['dirchmodfailure'] = 'A k&ouml;nyvt&aacute;r jogosults&aacute;gainak megv&aacute;ltoztat&aacute;sa nem siker&uuml;lt';
$lang['dirnotemptyconfirm'] = 'Ez a mappa nem &uuml;res. Biztos t&ouml;r&ouml;lsz minden tartalmat, bele&eacute;rtve az almapp&aacute;kat is?';
$lang['dirtreedeletecancelled'] = 'A mappa t&ouml;rl&eacute;s&eacute;t megszak&iacute;tottuk';
$lang['imsure'] = 'Biztos vagyok benne';
$lang['cancel'] = 'M&eacute;gsem';
$lang['ok'] = 'OK';
$lang['uploadnewfile'] = '&Uacute;j f&aacute;jl(ok) felt&ouml;lt&eacute;se:';
$lang['unpackafterupload'] = 'Megpr&oacute;b&aacute;ljuk kicsomagolni felt&ouml;lt&eacute;s ut&aacute;n (tgz &eacute;s a legt&ouml;bb zip-f&aacute;jl)?';
$lang['uploadsuccess'] = 'sikeresen fel lett t&ouml;ltve';
$lang['uploadfail'] = 'nem siker&uuml;lt felt&ouml;lteni';
$lang['unpacksuccess'] = 'sikeresen ki lett csomagolva';
$lang['unpackfail'] = ' nem siker&uuml;lt az al&aacute;bbi hib&aacute;val: ';
$lang['packfileopenfail'] = 'Nem siker&uuml;lt megnyitni a t&ouml;m&ouml;r&iacute;tett f&aacute;jlt (nem t&aacute;mogatott form&aacute;tum?)';
$lang['packfilewritefail'] = 'Nem siker&uuml;lt a(z) %s f&aacute;jlt &iacute;r&aacute;sra megnyitni';
$lang['currentpath'] = 'Aktu&aacute;lis &uacute;tvonal:';
$lang['newdirname'] = '&Uacute;j mapp l&eacute;trehoz&aacute;sa:';
$lang['newdirsuccess'] = 'A mapp&aacute;t sikeresen l&eacute;trehoztuk';
$lang['newdirfail'] = 'Hiba l&eacute;pett fel a mappa l&eacute;trehoz&aacute;sa k&ouml;zben';
$lang['filedateformat'] = 'h/n/&Eacute; &Oacute;:p:m';
$lang['iconsize'] = 'Ikon m&eacute;rete';
$lang['smallicons'] = 'Kis ikonok';
$lang['largeicons'] = 'Nagy ikonok';
$lang['thousanddelimiter'] = 'Ezres elv&aacute;laszt&oacute;';
$lang['none'] = 'Nincs';
$lang['showthumbnails'] = 'Miniat&uacute;r&ouml;k mutat&aacute;sa';
$lang['showthumbnailshelp'] = 'Ha ezt enged&eacute;lyezed, akkor a k&eacute;pf&aacute;jlok miniatűrjeit fogjuk mutatni (elrejtve magukat a miniat&uacute;r&ouml;ket reprezent&aacute;l&oacute; f&aacute;jlokat). Ha tiltod ezt az opci&oacute;t, akkor szimpl&aacute;n minden f&aacute;jl fel lesz sorolva.';
$lang['uploadfilesto'] = 'F&aacute;jlok felt&ouml;lt&eacute;se ide:';
$lang['uploadview'] = 'F&aacute;jlok felt&ouml;lt&eacute;se';
$lang['uploadboxes'] = 'Felt&ouml;ltő dobozok sz&aacute;ma';
$lang['nothinguploaded'] = 'Semmi nem lett felt&ouml;ltve';
$lang['unsupportedarchive'] = 'Nem t&aacute;mogatott arch&iacute;v form&aacute;tum';
$lang['uploadmethod'] = 'Felt&ouml;lt&eacute;s m&oacute;dja';
$lang['uploaderstandard'] = 'Standard html beviteli m&oacute;d (lehetőv&eacute; teszi a kicsomagol&aacute;st is)';
$lang['enableadvanced'] = 'Enged&eacute;lyezz&uuml;k a halad&oacute; m&oacute;dot?';
$lang['advancedhelp'] = 'Lehetőv&eacute; teszi a teljes cmsms f&aacute;jlrendszer el&eacute;r&eacute;s&eacute;t, nem csak az upload-ot';
$lang['showhiddenfileshelp'] = 'Csak halad&oacute; m&oacute;dban van hat&aacute;sa';
$lang['showhiddenfiles'] = 'Rejtett f&aacute;jlok mutat&aacute;sa';
$lang['settingsconfirmsingledelete'] = 'Megerős&iacute;ted egy f&aacute;jl t&ouml;rl&eacute;s&eacute;t?';
$lang['settingssaved'] = 'A be&aacute;ll&iacute;t&aacute;sokat mentett&uuml;k';
$lang['help'] = '		<h3>What does this do?</h3>
		<p>This module provides file management functions, eventually and hopefully replacing the rather aged builtin file management</p>
		<h3>How do I use it?</h3>
		<p>Select it from the content-menu from in the admin. While the old filemanager is still in there you should select the one furthest down in the menu.</p>';
$lang['utma'] = '156861353.1745742775.1167462096.1227524728.1227528035.121';
$lang['utmz'] = '156861353.1223837548.118.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>

==> cmsmadesimple-1.6.6.tgz: cms/modules/FileManager/lang/ext/hu_HU.php <==
<?php
$lang['friendlyname'] = 'F&aacute;jlkezelő';
$lang['permission'] = 'A f&aacute;jlkezelő haszn&aacute;lata';
$lang['permissionadvanced'] = 'A f&aacute;jlkezelő halad&oacute; haszn&aacute;lata';
$lang['moddescription'] = 'K&eacute;pek &eacute;s mapp&aacute;k kezel&eacute;se a cmsms felt&ouml;ltő szekci&oacute;j&aacute;ban';
$lang['installed'] = 'Install&aacute;lt f&aacute;jlkezelő verzi&oacute;: %s';
$lang['postinstall'] = 'A F&aacute;jlkezelő modul telep&iacute;t&eacute;se megt&ouml;rt&eacute;nt';
$lang['uninstalled'] = 'A f&aacute;jlkezelő modul elt&aacute;vol&iacute;t&aacute;sa megt&ouml;rt&eacute;nt.';
$lang['really_uninstall'] = 'Biztosan elt&aacute;vol&iacute;tod a F&aacute;jlkezelő modult?';
$lang['upgraded'] = 'A F&aacute;jlkezelő modult sikeresen friss&iacute;tett&uuml;k %s verzi&oacute;ra';
$lang['fileview'] = 'F&aacute;jl n&eacute;zet';
$lang['switchtofileview'] = 'V&aacute;lt&aacute;s f&aacute;jl n&eacute;zetre';
$lang['settings'] = 'Be&aacute;ll&iacute;t&aacute;sok';
$lang['savesettings'] = 'Be&aacute;ll&iacute;t&aacute;sok ment&eacute;se';
$lang['filename'] = 'F&aacute;jln&eacute;v';
$lang['fileinfo'] = 'F&aacute;jlinfo';
$lang['fileowner'] = 'Tulajdonos';
$lang['fileperms'] = 'Jogosults&aacute;gok';
$lang['filesize'] = 'M&eacute;ret';
$lang['filedate'] = 'D&aacute;tum';
$lang['actions'] = 'Műveletek';
$lang['delete'] = 'T&ouml;rl&eacute;s';
$lang['notwritable'] = 'Nem &iacute;rhat&oacute;';
$lang['filetoobig'] = 't&uacute;l nagy. A felt&ouml;lt&eacute;st f&eacute;lbeszak&iacute;tottuk.';
$lang['unknown'] = 'Ismeretlen';
$lang['fileoutsideuploads'] = 'Nem m&oacute;dos&iacute;thatsz f&aacute;jlokat az uploads k&ouml;nyvt&aacute;ron k&iacute;v&uuml;l! (Ehhez a &quot;Kiterjesztett f&aacute;jl kezel&eacute;s&quot; jogra van sz&uuml;ks&eacute;g)';
$lang['writable'] = '&Iacute;rhat&oacute;';
$lang['writeprotected'] = '&Iacute;r&aacute;sv&eacute;dett';
$lang['bytes'] = 'b&aacute;jt';
$lang['kb'] = 'KB';
$lang['mb'] = 'MB';
$lang['files'] = 'f&aacute;jlok';
$lang['bytesin'] = 'b&aacute;jt ebben:';
$lang['in'] = '-ban(/ben)';
$lang['file'] = 'f&aacute;jl';
$lang['fileno'] = 'F&aacute;jl sz&aacute;ma';
$lang['subdirs'] = 'almapp&aacute;k';
$lang['subdir'] = 'almappa';
$lang['and'] = '&eacute;s';
$lang['confirmsingledelete'] = 'Biztos vagy benne?';
$lang['confirmsingledirdelete'] = 'Biztos, hogy ezt a mapp&aacute;t t&ouml;r&ouml;lni akarod?';
$lang['dirtreedeletesuccess'] = 'A tartalommal is b&iacute;r&oacute; mapp&aacute;t sikeresen t&ouml;r&ouml;lt&uuml;k';
$lang['dirtreedeletefail'] = 'Hiba t&ouml;rt&eacute;nta mappa t&ouml;rl&eacute;se k&ouml;zben. Ennek ellen&eacute;re lehet, hogy a tartalm&aacute;b&oacute;l hi&aacute;nyzik ez-az.';
$lang['singlefiledeletesuccess'] = 'A f&aacute;jlt sikeresen t&ouml;r&ouml;lt&uuml;k';
$lang['filedeletesuccess'] = 'sikeresen t&ouml;r&ouml;lve lett';
$lang['singlefiledeletefail'] = 'Hiba k&ouml;vetkezett a f&aacute;jl t&ouml;rl&eacute;se k&ouml;zben';
$lang['filedeletefail'] = ' nem lett t&ouml;r&ouml;lve egy hiba miatt';
$lang['singledirdeletesuccess'] = 'A mappa sikeresen t&ouml;r&ouml;lve lett';
$lang['singledirdeletefail'] = 'Hiba k&ouml;vetkezett a mappa t&ouml;rl&eacute;se k&ouml;zben (&uuml;res egy&aacute;ltal&aacute;n?)';
$lang['deleteselected'] = 'Kijel&ouml;lt f&aacute;jlok t&ouml;rl&eacute;se';
$lang['confirmselected'] = 'Biztos vagy benne?';
$lang['confirmdeleteselected'] = 'Biztos t&ouml;rl&ouml;d a kijel&ouml;lt f&aacute;jlokat?';
$lang['deleteselectedcancelled'] = 'A kijel&ouml;lt f&aacute;jlok t&ouml;rl&eacute;s&eacute;t megszak&iacute;tottuk';
$lang['recursetext'] = 'Bel&eacute;p&eacute;s az alk&ouml;nyvt&aacute;rakba is (rekurzi&oacute;)';
$lang['nofilesselected'] = 'Nincs kijel&ouml;lve f&aacute;jl';
$lang['moveselected'] = 'Kijel&ouml;lt f&aacute;jlok mozgat&aacute;sa';
$lang['copyselected'] = 'Kijel&ouml;lt f&aacute;jlok m&aacute;sol&aacute;sa';
$lang['selecttargetdir'] = 'V&aacute;laszd ki a c&eacute;lk&ouml;nyvt&aacute;rat a m&aacute;sol&aacute;shoz/mozgat&aacute;shoz';
$lang['movedto'] = 'mozgatva';
$lang['copiedto'] = 'm&aacute;solva';
$lang['couldnotmove'] = 'nem siker&uuml;lt mozgatni';
$lang['couldnotcopy'] = 'nem siker&uuml;lt m&aacute;solni';
$lang['rename'] = '&Aacute;tnevez&eacute;s';
$lang['newname'] = '&Uacute;j n&eacute;v:';
$lang['renamesuccess'] = 'A f&aacute;jlt sikeresen &aacute;tnevezt&uuml;k.';
$lang['renamefailure'] = 'A f&aacute;jl &aacute;tnevez&eacute;se nem siker&uuml;lt.';
$lang['renamecancelled'] = 'Az &aacute;tnevez&eacute;st f&eacute;lbeszak&iacute;tottuk.';
$lang['owner'] = 'Tulajdonos';
$lang['group'] = 'Csoport';
$lang['others'] = 'Mindenki m&aacute;s';
$lang['newpermissions'] = '&Uacute;j jogosults&aacute;gok:';
$lang['setpermissions'] = 'Jogosults&aacute;gok be&aacute;ll&iacute;t&aacute;sa';
$lang['permissionstyle'] = 'Jogosults&aacute;gok fajt&aacute;ja';
$lang['rwxstyle'] = 'rwx t&iacute;pius';
$lang['755style'] = '755 t&iacute;pus';
$lang['quickmode'] = 'Gyors chmod (kb. 777)';
$lang['chmod'] = 'Jogosults&aacute;gok megv&aacute;ltoztat&aacute;sa';
$lang['chmodselected'] = 'Jogosults&aacute;gok megv&aacute;ltoztat&aacute;sa a kijel&ouml;lt f&aacute;jlokra';
$lang['chmodsuccess'] = 'A f&aacute;jl sikeresen megkapta az &uacute;j jogokat';
$lang['chmodfailure'] = 'A f&aacute;jl jogosults&aacute;g&aacute;nak megv&aacute;ltoztat&aacute;sa nem siker&uuml;lt';
$lang['chmodcancelled'] = 'A jogosults&aacute;gok megv&aacute;ltoztat&aacute;s&aacute;t f&eacute;lbeszak&iacute;tottuk.';
$lang['dirchmodfailmulti'] = 'A k&ouml;nyvt&aacute;r jogainak megv&aacute;ltoztat&aacute;sa nem siker&uuml;lt, ennek ellen&eacute;re bizonyos benne levő f&aacute;jlok jogosults&aacute;gai megv&aacute;ltozhattak.';
$lang['dirchmodsuccessmulti'] = 'A k&ouml;nyvt&aacute;r &eacute;s a benne foglalt f&aacute;jlok jogosults&aacute;gainak megv&aacute;ltoztat&aacute;sa sikeres volt';
$lang['dirchmodsuccess'] = 'A k&ouml;nyvt&aacute;r megkapta az &uacute;j jogokat';
$lang['dirchmodfailure'] = 'A k&ouml;nyvt&aacute;r jogosults&aacute;gainak megv&aacute;ltoztat&aacute;sa nem siker&uuml;lt';
$lang['dirnotemptyconfirm'] = 'Ez a mappa nem &uuml;res. Biztos t&ouml;r&ouml;lsz minden tartalmat, bele&eacute;rtve az almapp&aacute;kat is?';
$lang['dirtreedeletecancelled'] = 'A mappa t&ouml;rl&eacute;s&eacute;t megszak&iacute;tottuk';
$lang['imsure'] = 'Biztos vagyok benne';
$lang['cancel'] = 'M&eacute;gsem';
$lang['ok'] = 'Ok';
$lang['uploadnewfile'] = '&Uacute;j f&aacute;jl(ok) felt&ouml;lt&eacute;se:';
$lang['unpackafterupload'] = 'Megpr&oacute;b&aacute;ljuk kicsomagolni felt&ouml;lt&eacute;s ut&aacute;n (tgz &eacute;s a legt&ouml;bb zip-f&aacute;jl)?';
$lang['uploadsuccess'] = 'sikeresen fel lett t&ouml;ltve';
$lang['uploadfail'] = 'nem siker&uuml;lt felt&ouml;lteni';
$lang['unpacksuccess'] = 'sikeresen ki lett csomagolva';
$lang['unpackfail'] = ' nem siker&uuml;lt az al&aacute;bbi hib&aacute;val: ';
$lang['packfileopenfail'] = 'Nem siker&uuml;lt megnyitni a t&ouml;m&ouml;r&iacute;tett f&aacute;jlt (nem t&aacute;mogatott form&aacute;tum?)';
$lang['packfilewritefail'] = 'Nem siker&uuml;lt a(z) %s f&aacute;jlt &iacute;r&aacute;sra megnyitni';
$lang['currentpath'] = 'Aktu&aacute;lis &uacute;tvonal:';
$lang['newdirname'] = '&Uacute;j mapp l&eacute;trehoz&aacute;sa:';
$lang['newdirsuccess'] = 'A mapp&aacute;t sikeresen l&eacute;trehoztuk';
$lang['newdirfail'] = 'Hiba l&eacute;pett fel a mappa l&eacute;trehoz&aacute;sa k&ouml;zben';
$lang['invalidnewdir'] = 'A k&ouml;nyvt&aacute;r neve nem tartalmazhat /, \ &eacute;s &#039;..&#039; karaktersorozatokat';
$lang['filedateformat'] = 'h/n/&Eacute; &Oacute;:p:m';
$lang['iconsize'] = 'Ikon m&eacute;rete';
$lang['smallicons'] = 'Kis ikonok';
$lang['largeicons'] = 'Nagy ikonok';
$lang['thousanddelimiter'] = 'Ezres elv&aacute;laszt&oacute;';
$lang['none'] = 'Nincs';
$lang['space'] = 'sz&oacute;k&ouml;z';
$lang['showthumbnails'] = 'Miniat&uacute;r&ouml;k mutat&aacute;sa';
$lang['showthumbnailshelp'] = 'Ha ezt enged&eacute;lyezed, akkor a k&eacute;pf&aacute;jlok miniatűrjeit fogjuk mutatni (elrejtve magukat a miniat&uacute;r&ouml;ket reprezent&aacute;l&oacute; f&aacute;jlokat). Ha tiltod ezt az opci&oacute;t, akkor szimpl&aacute;n minden f&aacute;jl fel lesz sorolva.';
$lang['uploadfilesto'] = 'F&aacute;jlok felt&ouml;lt&eacute;se ide:';
$lang['uploadview'] = 'F&aacute;jlok felt&ouml;lt&eacute;se';
$lang['uploadboxes'] = 'Felt&ouml;ltő dobozok sz&aacute;ma';
$lang['nothinguploaded'] = 'Semmi nem lett felt&ouml;ltve';
$lang['unsupportedarchive'] = 'Nem t&aacute;mogatott arch&iacute;v form&aacute;tum';
$lang['uploadmethod'] = 'Felt&ouml;lt&eacute;s m&oacute;dja';
$lang['uploaderstandard'] = 'Standard html beviteli m&oacute;d (lehetőv&eacute; teszi a kicsomagol&aacute;st is)';
$lang['enableadvanced'] = 'Enged&eacute;lyezz&uuml;k a halad&oacute; m&oacute;dot?';
$lang['advancedhelp'] = 'Lehetőv&eacute; teszi a teljes cmsms f&aacute;jlrendszer el&eacute;r&eacute;s&eacute;t, nem csak az upload-ot';
$lang['showhiddenfileshelp'] = 'Csak halad&oacute; m&oacute;dban van hat&aacute;sa';
$lang['showhiddenfiles'] = 'Rejtett f&aacute;jlok mutat&aacute;sa';
$lang['settingsconfirmsingledelete'] = 'Megerős&iacute;ted egy f&aacute;jl t&ouml;rl&eacute;s&eacute;t?';
$lang['settingssaved'] = 'A be&aacute;ll&iacute;t&aacute;sokat mentett&uuml;k';
$lang['help'] = '		<h3>What does this do?</h3>
		<p>This module provides file management functions, eventually and hopefully replacing the rather aged builtin file management</p>
		<h3>How do I use it?</h3>
		<p>Select it from the content-menu from in the admin. While the old filemanager is still in there you should select the one furthest down in the menu.</p>';
$lang['utma'] = '156861353.1533605959.1224742544.1241159145.1241169959.16';
$lang['utmz'] = '156861353.1239430985.12.4.utmcsr=themes.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>
